==> integration-tests-jobs-service-springboot-1.40.1-20230625.030328-1-sources.jar: org/acme/processes/MultipleTimerInstancesTimerEventResource.java <==
/*
 * Copyright 2021 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.acme.processes;

import java.net.URI;
import java.util.Collection;
import java.util.List;
import java.util.Map;
import java.util.Optional;
import java.util.stream.Collectors;
import org.jbpm.util.JsonSchemaUtil;
import org.kie.kogito.process.Process;
import org.kie.kogito.process.ProcessInstance;
import org.kie.kogito.process.WorkItem;
import org.kie.kogito.process.ProcessService;
import org.kie.kogito.process.workitem.Attachment;
import org.kie.kogito.process.workitem.AttachmentInfo;
import org.kie.kogito.process.workitem.Comment;
import org.kie.kogito.process.workitem.Policies;
import org.kie.kogito.process.workitem.TaskModel;
import org.kie.kogito.auth.IdentityProvider;
import org.kie.kogito.auth.IdentityProviders;
import org.kie.kogito.auth.SecurityPolicy;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.PatchMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.server.ResponseStatusException;
import org.springframework.http.ResponseEntity;
import org.springframework.http.HttpStatus;
import org.springframework.web.util.UriComponents;
import org.springframework.web.util.UriComponentsBuilder;
import io.swagger.v3.oas.annotations.Operation;

@RestController
@RequestMapping("/MultipleTimerInstancesTimerEvent")
@org.springframework.stereotype.Component()
public class MultipleTimerInstancesTimerEventResource {

    @org.springframework.beans.factory.annotation.Autowired()
    @org.springframework.beans.factory.annotation.Qualifier("MultipleTimerInstancesTimerEvent")
    Process<MultipleTimerInstancesTimerEventModel> process;

    @Autowired
    ProcessService processService;

    @PostMapping(produces = MediaType.APPLICATION_JSON_VALUE, consumes = MediaType.APPLICATION_JSON_VALUE)
    @Operation(summary = "MultipleTimerInstancesTimerEvent", description = "")
    public ResponseEntity<MultipleTimerInstancesTimerEventModelOutput> createResource_MultipleTimerInstancesTimerEvent(@RequestHeader HttpHeaders httpHeaders, @RequestParam(value = "businessKey", required = false) String businessKey, @RequestBody(required = false) @javax.validation.Valid() @javax.validation.constraints.NotNull() MultipleTimerInstancesTimerEventModelInput resource, UriComponentsBuilder uriComponentsBuilder) {
        ProcessInstance<MultipleTimerInstancesTimerEventModel> pi = processService.createProcessInstance(process, businessKey, Optional.ofNullable(resource).orElse(new MultipleTimerInstancesTimerEventModelInput()).toModel(), httpHeaders, httpHeaders.getOrEmpty("X-KOGITO-StartFromNode").stream().findFirst().orElse(null));
        return ResponseEntity.created(uriComponentsBuilder.path("/MultipleTimerInstancesTimerEvent/{id}").buildAndExpand(pi.id()).toUri()).body(pi.checkError().variables().toModel());
    }

    @GetMapping(produces = MediaType.APPLICATION_JSON_VALUE)
    @Operation(summary = "MultipleTimerInstancesTimerEvent", description = "")
    public List<MultipleTimerInstancesTimerEventModelOutput> getResources_MultipleTimerInstancesTimerEvent() {
        return processService.getProcessInstanceOutput(process);
    }

    @GetMapping(value = "/schema", produces = MediaType.APPLICATION_JSON_VALUE)
    @Operation(summary = "MultipleTimerInstancesTimerEvent", description = "")
    public Map<String, Object> getResourceSchema_MultipleTimerInstancesTimerEvent() {
        return JsonSchemaUtil.load(this.getClass().getClassLoader(), process.id());
    }

    @GetMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE)
    @Operation(summary = "MultipleTimerInstancesTimerEvent", description = "")
    public MultipleTimerInstancesTimerEventModelOutput getResource_MultipleTimerInstancesTimerEvent(@PathVariable("id") String id) {
        return processService.findById(process, id).orElseThrow(() -> new ResponseStatusException(HttpStatus.NOT_FOUND));
    }

    @DeleteMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE)
    @Operation(summary = "MultipleTimerInstancesTimerEvent", description = "")
    public MultipleTimerInstancesTimerEventModelOutput deleteResource_MultipleTimerInstancesTimerEvent(@PathVariable("id") final String id) {
        return processService.delete(process, id).orElseThrow(() -> new ResponseStatusException(HttpStatus.NOT_FOUND));
    }

    @PutMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE, consumes = MediaType.APPLICATION_JSON_VALUE)
    @Operation(summary = "MultipleTimerInstancesTimerEvent", description = "")
    public MultipleTimerInstancesTimerEventModelOutput updateModel_MultipleTimerInstancesTimerEvent(@PathVariable("id") String id, @RequestBody(required = false) @javax.validation.Valid() @javax.validation.constraints.NotNull() MultipleTimerInstancesTimerEventModelInput resource) {
        return processService.update(process, id, resource.toModel()).orElseThrow(() -> new ResponseStatusException(HttpStatus.NOT_FOUND));
    }

    @PatchMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE, consumes = MediaType.APPLICATION_JSON_VALUE)
    @Operation(summary = "MultipleTimerInstancesTimerEvent", description = "")
    public MultipleTimerInstancesTimerEventModelOutput updateModelPartial_MultipleTimerInstancesTimerEvent(@PathVariable("id") String id, @RequestBody(required = false) @javax.validation.Valid() @javax.validation.constraints.NotNull() MultipleTimerInstancesTimerEventModelInput resource) {
        return processService.updatePartial(process, id, resource.toModel()).orElseThrow(() -> new ResponseStatusException(HttpStatus.NOT_FOUND));
    }

    @GetMapping(value = "/{id}/tasks", produces = MediaType.APPLICATION_JSON_VALUE)
    @Operation(summary = "MultipleTimerInstancesTimerEvent", description = "")
    public List<TaskModel> getTasks_MultipleTimerInstancesTimerEvent(@PathVariable("id") String id, @RequestParam(value = "user", required = false) final String user, @RequestParam(value = "group", required = false) final List<String> groups) {
        return processService.getTasks(process, id, SecurityPolicy.of(IdentityProviders.of(user, groups))).orElseThrow(() -> new ResponseStatusException(HttpStatus.NOT_FOUND)).stream().map(org.acme.processes.MultipleTimerInstancesTimerEvent_TaskModelFactory::from).collect(Collectors.toList());
    }
}

==> integration-tests-jobs-service-springboot-3.0.0-20231201.044652-1-sources.jar: org/acme/processes/MultipleTimerInstancesTimerEventResource.java <==
/*
 * Copyright 2021 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.acme.processes;

import java.net.URI;
import java.util.Collection;
import java.util.List;
import java.util.Map;
import java.util.Optional;
import java.util.stream.Collectors;
import org.jbpm.util.JsonSchemaUtil;
import org.kie.kogito.process.Process;
import org.kie.kogito.process.ProcessInstance;
import org.kie.kogito.process.WorkItem;
import org.kie.kogito.process.ProcessService;
import org.kie.kogito.process.workitem.Attachment;
import org.kie.kogito.process.workitem.AttachmentInfo;
import org.kie.kogito.process.workitem.Comment;
import org.kie.kogito.process.workitem.Policies;
import org.kie.kogito.process.workitem.TaskModel;
import org.kie.kogito.auth.IdentityProvider;
import org.kie.kogito.auth.IdentityProviders;
import org.kie.kogito.auth.SecurityPolicy;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.PatchMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.server.ResponseStatusException;
import org.springframework.http.ResponseEntity;
import org.springframework.http.HttpStatus;
import org.springframework.web.util.UriComponents;
import org.springframework.web.util.UriComponentsBuilder;
import io.swagger.v3.oas.annotations.Operation;

@RestController
@RequestMapping("/MultipleTimerInstancesTimerEvent")
@org.springframework.stereotype.Component()
public class MultipleTimerInstancesTimerEventResource {

    @org.springframework.beans.factory.annotation.Autowired()
    @org.springframework.beans.factory.annotation.Qualifier("MultipleTimerInstancesTimerEvent")
    Process<MultipleTimerInstancesTimerEventModel> process;

    @Autowired
    ProcessService processService;

    @PostMapping(produces = MediaType.APPLICATION_JSON_VALUE, consumes = MediaType.APPLICATION_JSON_VALUE)
    @Operation(summary = "MultipleTimerInstancesTimerEvent", description = "")
    public ResponseEntity<MultipleTimerInstancesTimerEventModelOutput> createResource_MultipleTimerInstancesTimerEvent(@RequestHeader HttpHeaders httpHeaders, @RequestParam(value = "businessKey", required = false) String businessKey, @RequestBody(required = false) @jakarta.validation.Valid() @jakarta.validation.constraints.NotNull() MultipleTimerInstancesTimerEventModelInput resource, UriComponentsBuilder uriComponentsBuilder) {
        ProcessInstance<MultipleTimerInstancesTimerEventModel> pi = processService.createProcessInstance(process, businessKey, Optional.ofNullable(resource).orElse(new MultipleTimerInstancesTimerEventModelInput()).toModel(), httpHeaders, httpHeaders.getOrEmpty("X-KOGITO-StartFromNode").stream().findFirst().orElse(null));
        return ResponseEntity.created(uriComponentsBuilder.path("/MultipleTimerInstancesTimerEvent/{id}").buildAndExpand(pi.id()).toUri()).body(pi.checkError().variables().toModel());
    }

    @GetMapping(produces = MediaType.APPLICATION_JSON_VALUE)
    @Operation(summary = "MultipleTimerInstancesTimerEvent", description = "")
    public List<MultipleTimerInstancesTimerEventModelOutput> getResources_MultipleTimerInstancesTimerEvent() {
        return processService.getProcessInstanceOutput(process);
    }

    @GetMapping(value = "/schema", produces = MediaType.APPLICATION_JSON_VALUE)
    @Operation(summary = "MultipleTimerInstancesTimerEvent", description = "")
    public Map<String, Object> getResourceSchema_MultipleTimerInstancesTimerEvent() {
        return JsonSchemaUtil.load(this.getClass().getClassLoader(), process.id());
    }

    @GetMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE)
    @Operation(summary = "MultipleTimerInstancesTimerEvent", description = "")
    public MultipleTimerInstancesTimerEventModelOutput getResource_MultipleTimerInstancesTimerEvent(@PathVariable("id") String id) {
        return processService.findById(process, id).orElseThrow(() -> new ResponseStatusException(HttpStatus.NOT_FOUND));
    }

    @DeleteMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE)
    @Operation(summary = "MultipleTimerInstancesTimerEvent", description = "")
    public MultipleTimerInstancesTimerEventModelOutput deleteResource_MultipleTimerInstancesTimerEvent(@PathVariable("id") final String id) {
        return processService.delete(process, id).orElseThrow(() -> new ResponseStatusException(HttpStatus.NOT_FOUND));
    }

    @PutMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE, consumes = MediaType.APPLICATION_JSON_VALUE)
    @Operation(summary = "MultipleTimerInstancesTimerEvent", description = "")
    public MultipleTimerInstancesTimerEventModelOutput updateModel_MultipleTimerInstancesTimerEvent(@PathVariable("id") String id, @RequestBody(required = false) @jakarta.validation.Valid() @jakarta.validation.constraints.NotNull() MultipleTimerInstancesTimerEventModelInput resource) {
        return processService.update(process, id, resource.toModel()).orElseThrow(() -> new ResponseStatusException(HttpStatus.NOT_FOUND));
    }

    @PatchMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE, consumes = MediaType.APPLICATION_JSON_VALUE)
    @Operation(summary = "MultipleTimerInstancesTimerEvent", description = "")
    public MultipleTimerInstancesTimerEventModelOutput updateModelPartial_MultipleTimerInstancesTimerEvent(@PathVariable("id") String id, @RequestBody(required = false) @jakarta.validation.Valid() @jakarta.validation.constraints.NotNull() MultipleTimerInstancesTimerEventModelInput resource) {
        return processService.updatePartial(process, id, resource.toModel()).orElseThrow(() -> new ResponseStatusException(HttpStatus.NOT_FOUND));
    }

    @GetMapping(value = "/{id}/tasks", produces = MediaType.APPLICATION_JSON_VALUE)
    @Operation(summary = "MultipleTimerInstancesTimerEvent", description = "")
    public List<TaskModel> getTasks_MultipleTimerInstancesTimerEvent(@PathVariable("id") String id, @RequestParam(value = "user", required = false) final String user, @RequestParam(value = "group", required = false) final List<String> groups) {
        return processService.getTasks(process, id, SecurityPolicy.of(IdentityProviders.of(user, groups))).orElseThrow(() -> new ResponseStatusException(HttpStatus.NOT_FOUND)).stream().map(org.acme.processes.MultipleTimerInstancesTimerEvent_TaskModelFactory::from).collect(Collectors.toList());
    }
}
